pm4py.objects package
=====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.objects.bpmn
   pm4py.objects.conversion
   pm4py.objects.dfg
   pm4py.objects.heuristics_net
   pm4py.objects.log
   pm4py.objects.ocel
   pm4py.objects.petri
   pm4py.objects.petri_net
   pm4py.objects.process_tree
   pm4py.objects.random_variables
   pm4py.objects.stochastic_petri
   pm4py.objects.transition_system
   pm4py.objects.trie

Module contents
---------------

.. automodule:: pm4py.objects
   :members:
   :undoc-members:
   :show-inheritance:
